import {
  ValidateBy,
  ValidationArguments,
  ValidationOptions,
  buildMessage,
} from 'class-validator';
import { Frequency } from '../../types/frequency.enum';

function isPunctual(args: ValidationArguments): boolean {
  if (
    args.object['frequency'] === Frequency.PUNCTUAL &&
    args.object['departure'] instanceof Date &&
    !Object.keys(args.object['schedule']).length
  )
    return true;
  return false;
}

function isRecurrent(args: ValidationArguments): boolean {
  if (
    args.object['frequency'] === Frequency.RECURRENT &&
    args.object['fromDate'] instanceof Date &&
    args.object['toDate'] instanceof Date &&
    Object.keys(args.object['schedule']).length
  )
    return true;
  return false;
}

export const isPunctualOrRecurrent = (args: ValidationArguments): boolean => {
  console.log('validator ');
  console.log(args.object);
  return isPunctual(args) || isRecurrent(args);
};

/* istanbul ignore next */
export function IsPunctualOrRecurrent(
  validationOptions?: ValidationOptions,
): PropertyDecorator {
  return ValidateBy(
    {
      name: '',
      constraints: [],
      validator: {
        validate: (value, args: ValidationArguments): boolean =>
          isPunctualOrRecurrent(args),
        defaultMessage: buildMessage(
          () =>
            `the departure, from date, to date and schedule  must be properly set on reccurent or punctual ad `,
          validationOptions,
        ),
      },
    },
    validationOptions,
  );
}
