import { CreateAdRequest } from '../../../domain/dtos/create-ad.request';
import { ScheduleDTO } from '../../../domain/dtos/create.schedule.dto';
import { RecurrentNormaliser } from '../../../domain/entities/recurrent-normaliser';
import { Frequency } from '../../../domain/types/frequency.enum';
describe('recurrent normalizer transformer for punctual ad ', () => {
  const recurrentNormaliser = new RecurrentNormaliser();
  it('should transform punctual ad into recurrent ad ', () => {
    const punctualAd: CreateAdRequest = {
      userUuid: '',
      frequency: Frequency.PUNCTUAL,
      departure: new Date('05-03-2023 12:39:39 '),
      schedule: {} as ScheduleDTO,
      addresses: [],
    };
    expect(recurrentNormaliser.fromDateResolver(punctualAd)).toBe(
      punctualAd.departure,
    );
    expect(recurrentNormaliser.toDateResolver(punctualAd)).toBe(
      punctualAd.departure,
    );
    expect(recurrentNormaliser.scheduleMonResolver(punctualAd)).toBeUndefined();
    expect(recurrentNormaliser.scheduleTueResolver(punctualAd)).toBeUndefined();
    expect(recurrentNormaliser.scheduleWedResolver(punctualAd)).toBe('12:39');
    expect(recurrentNormaliser.scheduleThuResolver(punctualAd)).toBeUndefined();
    expect(recurrentNormaliser.scheduleFriResolver(punctualAd)).toBeUndefined();
    expect(recurrentNormaliser.scheduleSatResolver(punctualAd)).toBeUndefined();
    expect(recurrentNormaliser.scheduleSunResolver(punctualAd)).toBeUndefined();
  });
  it('should leave recurrent ad as is', () => {
    const recurrentAd: CreateAdRequest = {
      userUuid: '',
      frequency: Frequency.RECURRENT,
      schedule: {
        mon: '08:30',
        tue: '08:30',
        wed: '09:00',
        fri: '09:00',
      },
      addresses: [],
    };
    expect(recurrentNormaliser.fromDateResolver(recurrentAd)).toBe(
      recurrentAd.departure,
    );
    expect(recurrentNormaliser.toDateResolver(recurrentAd)).toBe(
      recurrentAd.departure,
    );
    expect(recurrentNormaliser.scheduleMonResolver(recurrentAd)).toBe(
      recurrentAd.schedule.mon,
    );
    expect(recurrentNormaliser.scheduleTueResolver(recurrentAd)).toBe(
      recurrentAd.schedule.tue,
    );
    expect(recurrentNormaliser.scheduleWedResolver(recurrentAd)).toBe(
      recurrentAd.schedule.wed,
    );
    expect(recurrentNormaliser.scheduleThuResolver(recurrentAd)).toBe(
      recurrentAd.schedule.thu,
    );
    expect(recurrentNormaliser.scheduleFriResolver(recurrentAd)).toBe(
      recurrentAd.schedule.fri,
    );
    expect(recurrentNormaliser.scheduleSatResolver(recurrentAd)).toBe(
      recurrentAd.schedule.sat,
    );
    expect(recurrentNormaliser.scheduleSunResolver(recurrentAd)).toBe(
      recurrentAd.schedule.sun,
    );
  });
  it('should pass for each day of the week of a deprarture ', () => {
    const punctualAd: CreateAdRequest = {
      userUuid: '',
      frequency: Frequency.PUNCTUAL,
      departure: undefined,
      schedule: {} as ScheduleDTO,
      addresses: [],
    };
    punctualAd.departure = new Date('05-01-2023 ');
    expect(recurrentNormaliser.scheduleMonResolver(punctualAd)).toBe('00:00');
    punctualAd.departure = new Date('05-02-2023 06:32:45');
    expect(recurrentNormaliser.scheduleTueResolver(punctualAd)).toBe('06:32');
    punctualAd.departure = new Date('05-03-2023 10:21');
    expect(recurrentNormaliser.scheduleWedResolver(punctualAd)).toBe('10:21');
    punctualAd.departure = new Date('05-04-2023 11:06:00');
    expect(recurrentNormaliser.scheduleThuResolver(punctualAd)).toBe('11:06');
    punctualAd.departure = new Date('05-05-2023 05:20');
    expect(recurrentNormaliser.scheduleFriResolver(punctualAd)).toBe('05:20');
    punctualAd.departure = new Date('05-06-2023');
    expect(recurrentNormaliser.scheduleSatResolver(punctualAd)).toBe('00:00');
    punctualAd.departure = new Date('05-07-2023');
    expect(recurrentNormaliser.scheduleSunResolver(punctualAd)).toBe('00:00');
  });
});
